package ru.dima.weather.cli;

import ru.dima.weather.provider.WeatherProvider;
import ru.dima.weather.provider.WeatherProviderRegistry;

public class WeatherProviderCLISelector {
    private CLIInputReader cliInputReader;
    private WeatherProviderRegistry weatherProviderRegistry;

    public WeatherProviderCLISelector(CLIInputReader cliInputReader, WeatherProviderRegistry weatherProviderRegistry) {
        this.cliInputReader = cliInputReader;
        this.weatherProviderRegistry = weatherProviderRegistry;
    }

    public WeatherProvider selectWeatherProviderFromCLI() {
        System.out.println("Для продолжения выбери сервис, предоставляющие погоду из представленных ниже.");
        System.out.println("Доступные сервисы погоды:");

        var weatherProviders = weatherProviderRegistry.getAllWeatherProviders();
        for (var weatherProviderIndex = 0; weatherProviderIndex < weatherProviders.size(); weatherProviderIndex ++) {
            var weatherProvider = weatherProviders.get(weatherProviderIndex);
            System.out.println((weatherProviderIndex + 1) + ". '" + weatherProvider.getName() + "'");
        }

        var weatherProviderIndexSelectedByUser = requestWeatherProviderIndexFromCLI();
        while (weatherProviderIndexSelectedByUser < 1 || weatherProviderIndexSelectedByUser > weatherProviders.size()) {
            System.out.println("Число должно быть от 1 до " + weatherProviders.size() + ". Попробуй еще раз.");
            weatherProviderIndexSelectedByUser = requestWeatherProviderIndexFromCLI();
        }

        return weatherProviders.get(weatherProviderIndexSelectedByUser - 1);
    }

    private int requestWeatherProviderIndexFromCLI() {
        System.out.print(">> Введите номер сервиса: ");
        return cliInputReader.readInteger();
    }
}
