package ru.dima.weather.provider;

import org.json.JSONObject;
import ru.dima.weather.http.HttpRequester;

import java.util.Map;
import java.util.stream.Collectors;


public class OpenWeatherMapWeatherProvider implements WeatherProvider {

    private HttpRequester httpRequester;
    private String openWeatherMapAccessToken;

    public static final String OPEN_WEATHER_MAP_BASE_FORECAST_URL = "https://api.openweathermap.org/data/2.5/forecast";
    public static final String OPEN_WEATHER_MAP_CITY_NAME_QUERY = "q";
    public static final String OPEN_WEATHER_MAP_ACCESS_TOKEN_QUERY = "appid";

    public static final String NAME = "open-weather-map";

    public OpenWeatherMapWeatherProvider(HttpRequester httpRequester, String openWeatherMapAccessToken) {
        this.httpRequester = httpRequester;
        this.openWeatherMapAccessToken = openWeatherMapAccessToken;
    }

    @Override
    public MultiDaysWeatherInfo getWeeklyWeatherInCity(String cityName) {
        var weatherResponse = httpRequester.getString(getWeeklyWeatherRequestUrl(cityName));
        var jsonObject = new JSONObject(weatherResponse);
        var weatherArray = jsonObject.getJSONArray("list");
        var resultWeeklyWeather = new MultiDaysWeatherInfo();

        for (var day = 0; day < 7; day ++) {
            var forecast = weatherArray.getJSONObject(day);
            var mainData = forecast.getJSONObject("main");

            var temperature = mainData.getDouble("temp");
            resultWeeklyWeather.perDayWeather.add(new WeatherInfo(temperature));
        }

        return resultWeeklyWeather;
    }

    @Override
    public String getName() {
        return NAME;
    }

    private String getWeeklyWeatherRequestUrl(String cityName) {
        var queryString = Map.of(
                OPEN_WEATHER_MAP_CITY_NAME_QUERY, cityName,
                OPEN_WEATHER_MAP_ACCESS_TOKEN_QUERY, openWeatherMapAccessToken,
                "units", "metric"
        ).entrySet().stream()
            .map(queryParameter -> queryParameter.getKey() + "=" + queryParameter.getValue())
            .collect(Collectors.joining("&"));

        return OPEN_WEATHER_MAP_BASE_FORECAST_URL + "?" + queryString;
    }
}
